@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3baudiodoc.cpp 409816 2005-05-05 18:43:39Z trueg $
+ * $Id: k3baudiodoc.cpp 474610 2005-10-26 20:49:57Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -174,7 +174,7 @@ void K3bAudioDoc::addUrls( const KURL::List& urls )
 
 void K3bAudioDoc::addTracks( const KURL::List& urls, uint position )
 {
-  KURL::List allUrls = extractUrlList( urls );
+  KURL::List allUrls = extractUrlList( K3b::convertToLocalUrls(urls) );
   for( KURL::List::iterator it = allUrls.begin(); it != allUrls.end(); it++, position++ ) {
     KURL& url = *it;
     if( url.path().right(3).lower() == "cue" ) {
@@ -339,7 +339,7 @@ K3bAudioTrack* K3bAudioDoc::importCueFile( const QString& cuefile, K3bAudioTrack
     if( !parser.cdText().performer().isEmpty() )
       setPerformer( parser.cdText().performer() );
 
-    K3bAudioDecoder* decoder = getDecoderForUrl( parser.imageFilename() );
+    K3bAudioDecoder* decoder = getDecoderForUrl( KURL::fromPathOrURL( parser.imageFilename() ) );
     if( decoder ) {
       K3bAudioFile* newFile = 0;
       unsigned int i = 0;
@@ -355,6 +355,12 @@ K3bAudioTrack* K3bAudioDoc::importCueFile( const QString& cuefile, K3bAudioTrack
 	newTrack->addSource( newFile );
 	newTrack->moveAfter( after );
 
+	// we do not know the length of the source yet so we have to force the index value
+	if( track.index0() > 0 )
+	  newTrack->m_index0Offset = track.length() - track.index0();
+	else
+	  newTrack->m_index0Offset = 0;
+
 	// cd-text
 	newTrack->setTitle( parser.cdText()[i].title() );
 	newTrack->setPerformer( parser.cdText()[i].performer() );
