@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdatadoc.cpp 430262 2005-06-30 17:44:20Z trueg $
+ * $Id: k3bdatadoc.cpp 474610 2005-10-26 20:49:57Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -126,11 +126,13 @@ void K3bDataDoc::addUrls( const KURL::List& urls )
 }
 
 
-void K3bDataDoc::addUrls( const KURL::List& urls, K3bDirItem* dir )
+void K3bDataDoc::addUrls( const KURL::List& l, K3bDirItem* dir )
 {
   if( !dir )
     dir = root();
 
+ KURL::List urls = K3b::convertToLocalUrls(l);
+
   for( KURL::List::ConstIterator it = urls.begin(); it != urls.end(); ++it ) {
     const KURL& url = *it;
     QString k3bname = (*it).path().section( '/', -1 );
@@ -166,8 +168,10 @@ void K3bDataDoc::addUrls( const KURL::List& urls, K3bDirItem* dir )
 
     // QFileInfo::exists and QFileInfo::isReadable return false for broken symlinks :(
     if( f.isDir() && !f.isSymLink() ) {
-      if( !newDirItem )
+      if( !newDirItem ) {
 	newDirItem = new K3bDirItem( k3bname, this, dir );
+      	newDirItem->setLocalPath( url.path() ); // HACK: see k3bdiritem.h
+      }
       
       // recursively add all the files in the directory
       QStringList dlist = QDir( f.absFilePath() ).entryList( QDir::All|QDir::System|QDir::Hidden );
@@ -1082,7 +1086,9 @@ void K3bDataDoc::setMultiSessionMode( K3bDataDoc::MultiSessionMode mode )
 bool K3bDataDoc::importSession( K3bDevice::Device* device )
 {
   K3bDevice::DiskInfo diskInfo = device->diskInfo();
-  if( !diskInfo.appendable() )
+  // DVD+RW media is reported as non-appendable
+  if( !diskInfo.appendable() &&
+      !(diskInfo.mediaType() & (K3bDevice::MEDIA_DVD_PLUS_RW|K3bDevice::MEDIA_DVD_RW_OVWR)) )
     return false;
 
   K3bDevice::Toc toc = device->readToc();
