@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdatajob.cpp 397759 2005-03-15 10:06:38Z trueg $
+ * $Id: k3bdatajob.cpp 475317 2005-10-28 21:06:04Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -98,8 +98,8 @@ K3bDataJob::K3bDataJob( K3bDataDoc* doc, K3bJobHandler* hdl, QObject* parent )
 
 K3bDataJob::~K3bDataJob()
 {
-  delete d;
   delete d->tocFile;
+  delete d;
 }
 
 
@@ -391,6 +391,7 @@ void K3bDataJob::slotWriterJobFinished( bool success )
       }
       d->verificationJob->setDoc( d->doc );
       d->verificationJob->setDevice( d->doc->burner() );
+      d->verificationJob->setUsedMultiSessionMode( d->usedMultiSessionMode );
 
       emit newTask( i18n("Verifying written data") );
       emit burning(false);
@@ -704,8 +705,12 @@ void K3bDataJob::determineMultiSessionMode()
     // 3. space left on appendable media >= project size (otherwise no ms)
     // 4. size of the project >= size of the media*90% (fill up?)
     
+    int wantedMediaState = K3bDevice::STATE_INCOMPLETE|K3bDevice::STATE_EMPTY;
+    if( d->doc->size() != d->doc->burningSize() ) // this means that an old session has been imported.
+      wantedMediaState = K3bDevice::STATE_INCOMPLETE;
+    
     int m = waitForMedia( d->doc->burner(), 
-			  K3bDevice::STATE_INCOMPLETE|K3bDevice::STATE_EMPTY,
+			  wantedMediaState,
 			  K3bDevice::MEDIA_WRITABLE_CD );
     
     if( m < 0 )
@@ -730,18 +735,17 @@ void K3bDataJob::determineMultiSessionMode()
 
 void K3bDataJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
 {
-  // TODO: in the future we should also check the last session's datamode and reuse it for the next session
-
   const K3bDevice::DiskInfo& info = dh->diskInfo();
 
   if( info.appendable() ) {
     //
     // 3 cases:
     //  1. the project does not fit -> no multisession (resulting in asking for another media above)
+    //     Except if an old session has been imported.
     //  2. the project does fit and fills up the CD -> finish multisession
     //  3. the project does fit and does not fill up the CD -> continue multisession
     //
-    if( d->doc->size() > info.remainingSize().mode1Bytes() )
+    if( d->doc->size() > info.remainingSize().mode1Bytes() && d->doc->size() == d->doc->burningSize() )
       d->usedMultiSessionMode = K3bDataDoc::NONE;
     else if( d->doc->size() >= info.remainingSize().mode1Bytes()*9/10 )
       d->usedMultiSessionMode = K3bDataDoc::FINISH;
@@ -753,7 +757,8 @@ void K3bDataJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
     //
     // We only close the CD if the project fills up the CD almost completely (90%)
     //
-    if( d->doc->size() >= info.capacity().mode1Bytes()*9/10 )
+    if( d->doc->size() >= info.capacity().mode1Bytes()*9/10 ||
+	d->doc->writingMode() == K3b::DAO )
       d->usedMultiSessionMode = K3bDataDoc::NONE;
     else
       d->usedMultiSessionMode = K3bDataDoc::START;
@@ -764,7 +769,8 @@ void K3bDataJob::slotDetermineMultiSessionMode( K3bDevice::DeviceHandler* dh )
     // Now we decide only based on the project size.
     // let's just use a 680 MB CD as our reference
     //
-    if( d->doc->size()/1024/1024 >= 680*9/10 )
+    if( d->doc->size()/1024/1024 >= 680*9/10 ||
+	d->doc->writingMode() == K3b::DAO )
       d->usedMultiSessionMode = K3bDataDoc::NONE;
     else
       d->usedMultiSessionMode = K3bDataDoc::START;
