@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdvdjob.cpp 427010 2005-06-19 07:08:21Z trueg $
+ * $Id: k3bdvdjob.cpp 475316 2005-10-28 21:04:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -258,7 +258,7 @@ void K3bDvdJob::slotIsoImagerFinished( bool success )
     return;
   }
 
-  d->imageError = success;
+  d->imageError = !success;
 
   if( m_doc->onTheFly() && m_writerJob )
     m_writerJob->closeFd();
@@ -522,6 +522,7 @@ void K3bDvdJob::determineMultiSessionMode()
 
   if( m < 0 ) {
     cancel();
+    emit finished(false);
   }
   else {
      connect( K3bDevice::sendCommand( K3bDevice::DeviceHandler::NG_DISKINFO, m_doc->burner() ), 
@@ -697,7 +698,7 @@ bool K3bDvdJob::waitForDvd()
 
 	else {
 	  // check if the writer supports writing sequential and thus multisession
-	  if( !m_doc->burner()->featureCurrent( K3bDevice::FEATURE_INCREMENTAL_STREAMING_WRITABLE ) ) {
+	  if( m_doc->burner()->featureCurrent( K3bDevice::FEATURE_INCREMENTAL_STREAMING_WRITABLE ) == 0 ) {
 	    if( KMessageBox::warningYesNo( qApp->activeWindow(),
 					   i18n("Your writer (%1 %2) does not support Incremental Streaming with %3 "
 						"media. Multisession will not be possible. Continue anyway?")
