@@ -1,6 +1,6 @@
 /*
  *
- * $Id: main.cpp 426859 2005-06-18 18:15:00Z trueg $
+ * $Id: main.cpp 476670 2005-11-01 19:12:27Z trueg $
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2005 Sebastian Trueg <trueg@k3b.org>
@@ -29,6 +29,7 @@
 #include <qfile.h>
 #include <qcstring.h>
 #include <qdatastream.h>
+#include <qtimer.h>
 
 #include <stdlib.h>
 
@@ -38,7 +39,7 @@
 
 #include <config.h>
 
-static const char* appVersion = "0.12.2";
+static const char* appVersion = "0.12.7";
 static const char* description = I18N_NOOP("A CD and DVD burning application");
 
 
@@ -113,7 +114,9 @@ int main( int argc, char* argv[] )
 		  << " current is: " << KGlobal::locale()->language() << endl;
   
     K3bApplication app;
-    app.init();
+
+    // we need a running app for the init method
+    QTimer::singleShot( 0, &app, SLOT(init()) );
 
     return app.exec();
   }
