@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdimagewritingdialog.cpp 430267 2005-06-30 17:52:11Z trueg $
+ * $Id: k3bcdimagewritingdialog.cpp 471081 2005-10-16 10:55:47Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -553,12 +553,12 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
   K3bListViewItem* isoRootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						      i18n("Detected:"),
 						      i18n("Iso9660 image") );
-  isoRootItem->setForegroundColor( 0, Qt::gray );
+  isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
   isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
 
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
 					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(isoF->fileName())) ) );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -566,7 +566,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().systemId.isEmpty()
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().systemId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -574,7 +574,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().volumeId.isEmpty() 
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().volumeId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -582,7 +582,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().volumeSetId.isEmpty()
 			      ? QString("-")
 			      : isoF->primaryDescriptor().volumeSetId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -590,14 +590,14 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().publisherId.isEmpty() 
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().publisherId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Preparer Id:"), 
 			      isoF->primaryDescriptor().preparerId.isEmpty() 
 			      ? QString("-") : isoF->primaryDescriptor().preparerId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
@@ -605,7 +605,7 @@ void K3bCdImageWritingDialog::createIso9660InfoItems( K3bIso9660* isoF )
 			      isoF->primaryDescriptor().applicationId.isEmpty()
 			      ? QString("-") 
 			      : isoF->primaryDescriptor().applicationId );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   isoRootItem->setOpen( true );
 }
@@ -616,24 +616,24 @@ void K3bCdImageWritingDialog::createCdrecordCloneItems( const QString& tocFile,
   K3bListViewItem* isoRootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						      i18n("Detected:"),
 						      i18n("Cdrecord clone image") );
-  isoRootItem->setForegroundColor( 0, Qt::gray );
+  isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
   isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
 
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
 					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Image file:"), 
 			      imageFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("TOC file:"), 
 			      tocFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   isoRootItem->setOpen( true );
 }
@@ -644,24 +644,24 @@ void K3bCdImageWritingDialog::createCueBinItems( const QString& cueFile, const Q
   K3bListViewItem* isoRootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						      i18n("Detected:"),
 						      i18n("Cue/bin image") );
-  isoRootItem->setForegroundColor( 0, Qt::gray );
+  isoRootItem->setForegroundColor( 0, palette().disabled().foreground() );
   isoRootItem->setPixmap( 0, SmallIcon( "cdimage") );
 
   K3bListViewItem* item = new K3bListViewItem( isoRootItem, m_infoView->lastItem(),
 					       i18n("Filesize:"), KIO::convertSize( K3b::filesize(KURL::fromPathOrURL(imageFile)) ) );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Image file:"), 
 			      imageFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   item = new K3bListViewItem( isoRootItem, 
 			      m_infoView->lastItem(),
 			      i18n("Cue file:"), 
 			      cueFile );
-  item->setForegroundColor( 0, Qt::gray );
+  item->setForegroundColor( 0, palette().disabled().foreground() );
 
   isoRootItem->setOpen( true );
 }
@@ -672,7 +672,7 @@ void K3bCdImageWritingDialog::createAudioCueItems( const K3bCueFileParser& cp )
   K3bListViewItem* rootItem = new K3bListViewItem( m_infoView, m_infoView->lastItem(),
 						   i18n("Detected:"),
 						   i18n("Audio Cue Image") );
-  rootItem->setForegroundColor( 0, Qt::gray );
+  rootItem->setForegroundColor( 0, palette().disabled().foreground() );
   rootItem->setPixmap( 0, SmallIcon( "sound") );
 
   K3bListViewItem* trackParent = new K3bListViewItem( rootItem,
@@ -803,7 +803,7 @@ void K3bCdImageWritingDialog::calculateMd5Sum( const QString& file )
     d->md5SumItem = new K3bListViewItem( m_infoView, m_infoView->firstChild() );
 
   d->md5SumItem->setText( 0, i18n("Md5 Sum:") );
-  d->md5SumItem->setForegroundColor( 0, Qt::gray );
+  d->md5SumItem->setForegroundColor( 0, palette().disabled().foreground() );
   d->md5SumItem->setProgress( 1, 0 );
   d->md5SumItem->setPixmap( 0, SmallIcon( "exec") );
   d->md5SumItem->setButton( 1, false );
@@ -874,9 +874,11 @@ void K3bCdImageWritingDialog::loadUserDefaults( KConfigBase* c )
 
   m_writerSelectionWidget->loadConfig( c );
 
-  QString image = c->readPathEntry( "image path", c->readPathEntry( "last written image" ) );
-  if( QFile::exists( image ) )
-    m_editImagePath->setURL( image );
+  if( !d->imageForced ) {
+    QString image = c->readPathEntry( "image path", c->readPathEntry( "last written image" ) );
+    if( QFile::exists( image ) )
+      m_editImagePath->setURL( image );
+  }
 
   QString imageType = c->readEntry( "image type", "auto" );
   int x = 0;
