@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bexternalbinwidget.cpp 281500 2004-01-21 10:20:23Z trueg $
+ * $Id: k3bexternalbinwidget.cpp 431907 2005-07-05 14:34:37Z hasso $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -101,7 +101,7 @@ K3bExternalBinWidget::K3bExternalBinWidget( K3bExternalBinManager* manager, QWid
   mainGrid->setSpacing( KDialog::spacingHint() );
 
   m_mainTabWidget = new QTabWidget( this );
-  m_rescanButton = new QPushButton( i18n("Search"), this );
+  m_rescanButton = new QPushButton( i18n("&Search"), this );
   mainGrid->addMultiCellWidget( m_mainTabWidget, 0, 0, 0, 1 );
   mainGrid->addWidget( m_rescanButton, 1, 1 );
   mainGrid->setColStretch( 0, 1 );
